==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/captchaforms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>CaptchaForms</name>
    <message>
        <source>CAPTCHA Forms</source>
        <translation>CAPTCHA Form</translation>
    </message>
    <message>
        <source>CAPTCHA Challenges</source>
        <translation>CAPTCHA Challenges</translation>
    </message>
    <message>
        <source>CAPTCHA Challenge - %1</source>
        <translation>CAPTCHA Challenge - %1</translation>
    </message>
    <message>
        <source>CAPTCHA Challenge</source>
        <translation>CAPTCHA Challenge</translation>
    </message>
    <message>
        <source>Describe the sound you hear</source>
        <translation>Beschreiben Sie den Ton, den Sie hören</translation>
    </message>
    <message>
        <source>Enter the text you see</source>
        <translation>Geben Sie den Text ein, den Sie sehen</translation>
    </message>
    <message>
        <source>Answer the question you see</source>
        <translation>Beantworten Sie die Frage, die Sie sehen</translation>
    </message>
    <message>
        <source>Identify the picture</source>
        <translation>Identifizieren Sie das Bild</translation>
    </message>
    <message>
        <source>Answer the question you hear</source>
        <translation>Beantworten Sie die Frage, die Sie hören</translation>
    </message>
    <message>
        <source>Enter the words you hear</source>
        <translation>Geben Sie die Wörter ein, die Sie hören</translation>
    </message>
    <message>
        <source>Answer the question in the video</source>
        <translation>Beantworten Sie die Frage im Video</translation>
    </message>
    <message>
        <source>Identify the video</source>
        <translation>Identifizieren Sie das Video</translation>
    </message>
    <message>
        <source>You have received the CAPTCHA challenge</source>
        <translation>Sie haben das CAPTCHA Challenge erhalten</translation>
    </message>
    <message>
        <source>Allows to undergo tests on humanity without the use of browser</source>
        <translation>Ermöglicht die Tests auf Menschlichkeit ohne das Benutzen eines Browsers</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/captchaforms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>CaptchaForms</name>
    <message>
        <source>CAPTCHA Forms</source>
        <translation>CAPTCHA Formulare</translation>
    </message>
    <message>
        <source>CAPTCHA Challenge - %1</source>
        <translation>CAPTCHA Anfrage - %1</translation>
    </message>
    <message>
        <source>CAPTCHA Challenge</source>
        <translation>CAPTCHA Anfrage</translation>
    </message>
    <message>
        <source>Describe the sound you hear</source>
        <translation>Beschreiben Sie den Ton, den Sie hören</translation>
    </message>
    <message>
        <source>Enter the text you see</source>
        <translation>Geben Sie den Text ein, den Sie sehen</translation>
    </message>
    <message>
        <source>Answer the question you see</source>
        <translation>Beantworten Sie die Frage, die Sie sehen</translation>
    </message>
    <message>
        <source>Identify the picture</source>
        <translation>Identifizieren Sie das Bild</translation>
    </message>
    <message>
        <source>Answer the question you hear</source>
        <translation>Beantworten Sie die Frage, die Sie hören</translation>
    </message>
    <message>
        <source>Enter the words you hear</source>
        <translation>Geben Sie die Wörter ein, die Sie hören</translation>
    </message>
    <message>
        <source>Answer the question in the video</source>
        <translation>Beantworten Sie die Frage im Video</translation>
    </message>
    <message>
        <source>Identify the video</source>
        <translation>Identifizieren Sie das Video</translation>
    </message>
    <message>
        <source>You have received the CAPTCHA challenge</source>
        <translation>Sie haben die CAPTCHA Anfrage erhalten</translation>
    </message>
    <message>
        <source>Allows to undergo tests on humanity without the use of browser</source>
        <translation>Ermöglicht Tests auf Menschlichkeit ohne das Benutzen eines Browsers</translation>
    </message>
    <message>
        <source>When receiving a CAPTCHA challenge</source>
        <translation>Wenn sie eine CHAPTCHA Anfrage erhalten</translation>
    </message>
</context>
</TS>
